/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { ImageProps } from 'react-native';
import { StyledComponentProps } from '../../theme';
interface ComponentProps {
    shape?: string;
    size?: string;
}
export declare type AvatarProps = StyledComponentProps & ImageProps & ComponentProps;
export declare type AvatarElement = React.ReactElement<AvatarProps>;
/**
 * `Avatar` is a styled `Image` component.
 *
 * @extends React.Component
 *
 * @property {string} shape - Determines the shape of the component.
 * Can be `round`, `rounded` or `square`.
 * Default is `round`.
 *
 * @property {string} size - Determines the size of the component.
 * Can be `tiny`, `small`, `medium`, `large`, or `giant`.
 * Default is `medium`.
 *
 * @property {ImageProps} ...ImageProps - Any props applied to Image component.
 *
 * @overview-example AvatarSimpleUsage
 *
 * @overview-example AvatarSize
 *
 * @overview-example AvatarShape
 *
 * @example AvatarRemoteImages
 *
 * @example AvatarInlineStyling
 */
export declare class AvatarComponent extends React.Component<AvatarProps> {
    static styledComponentName: string;
    private getComponentStyle;
    render(): React.ReactElement<ImageProps>;
}
export declare const Avatar: import("../../theme").StyledComponentClass<AvatarProps>;
export {};
