/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { StyleType } from '../../theme';
import { ViewProps } from 'react-native';
import { CalendarPickerCellProps } from './components/picker/calendarPickerCell.component';
import { CalendarDateInfo, CalendarViewMode } from './type';
import { DateService } from './service/date.service';
import { CalendarDataService, DateBatch } from './service/calendarData.service';
export interface BaseCalendarProps<D = Date> extends ViewProps {
    min?: D;
    max?: D;
    dateService?: DateService<D>;
    boundingMonth?: boolean;
    startView?: CalendarViewMode;
    title?: (date: D, viewMode: CalendarViewMode) => string;
    todayTitle?: (date: D) => string;
    filter?: (date: D) => boolean;
    renderFooter?: () => React.ReactElement;
    renderDay?: (info: CalendarDateInfo<D>, style: StyleType) => React.ReactElement;
    renderMonth?: (info: CalendarDateInfo<D>, style: StyleType) => React.ReactElement;
    renderYear?: (info: CalendarDateInfo<D>, style: StyleType) => React.ReactElement;
    themedStyle?: StyleType;
}
interface State<D> {
    viewMode: CalendarViewMode;
    visibleDate: D;
}
export declare type BaseCalendarElement<D> = React.ReactElement<BaseCalendarProps<D>>;
export declare abstract class BaseCalendarComponent<P, D = Date> extends React.Component<BaseCalendarProps<D> & P, State<D>> {
    static defaultProps: Partial<BaseCalendarProps>;
    state: State<D>;
    protected abstract onDaySelect(item: any): void;
    protected abstract isDaySelected(date: CalendarDateInfo<D>): boolean;
    protected abstract getSelectedDate(): D;
    protected abstract getDayPickerData(date: CalendarDateInfo<D>): DateBatch<D>;
    protected abstract shouldUpdateDayElement(props: CalendarPickerCellProps<D>, nextProps: CalendarPickerCellProps<D>): boolean;
    protected dataService: CalendarDataService<D>;
    protected get dateService(): DateService<D>;
    private get min();
    private get max();
    private calendarDayPagerRef;
    private calendarYearPagerRef;
    scrollToToday: () => void;
    private onSelect;
    private onMonthSelect;
    private onYearSelect;
    private onDayPickerPagerSelect;
    private onYearPickerPagerSelect;
    private onPickerNavigationPress;
    private onHeaderNavigationLeftPress;
    private onHeaderNavigationRightPress;
    private shouldUpdateDayItem;
    getCalendarStyle: (source: StyleType) => StyleType;
    private getWeekdayStyle;
    private getIsDaySelected;
    private isMonthSelected;
    private isYearSelected;
    isDayDisabled: (date: CalendarDateInfo<D>) => boolean;
    private isMonthDisabled;
    private isYearDisabled;
    isDayToday: (date: CalendarDateInfo<D>) => boolean;
    private isMonthToday;
    private isYearToday;
    private isDateFitsFilter;
    private isDayPickerInViewPort;
    private isYearPickerInViewPort;
    private createHeaderTitle;
    private getCurrentPagerRef;
    private isLateralNavigationAllowed;
    private renderDayIfNeeded;
    private renderWeekdayElement;
    private renderDayElement;
    private renderMonthElement;
    private renderYearElement;
    private renderDayPickerElement;
    private renderDayPickerPagerElement;
    private renderMonthPickerElement;
    private renderYearPickerElement;
    private renderYearPickerPagerElement;
    private renderPickerElement;
    private renderCalendarFooter;
    private renderCalendarHeader;
    render(): React.ReactElement<ViewProps>;
}
export {};
