import React from 'react';
import { BaseCalendarComponent, BaseCalendarProps } from './baseCalendar.component';
import { StyledComponentProps } from '../../theme';
import { CalendarDateInfo } from './type';
import { CalendarPickerCellProps } from './components/picker/calendarPickerCell.component';
import { DateBatch } from './service/calendarData.service';
interface ComponentProps<D = Date> {
    date?: D;
    onSelect: (date: D) => void;
}
export declare type CalendarProps<D = Date> = ComponentProps<D> & BaseCalendarProps<D> & StyledComponentProps;
export declare type CalendarElement<D = Date> = React.ReactElement<CalendarProps<D>>;
/**
 * Styled `Calendar` component.
 * Supports locales and different date objects like Moment.js or date-fns.
 * Composes date picker components in a horizontal pageable list.
 *
 * @extends React.Component
 *
 * @property {D} min - Minimal date that is able to be selected.
 *
 * @property {D} max - Maximum date that is able to be selected.
 *
 * @property {D} date - Date which is currently selected.
 *
 * @property {DateService<D>} dateService - Date service that is able to work with a date objects.
 * Defaults to Native Date service that works with JS Date.
 * Allows using different types of date like Moment.js or date-fns.
 *
 * @property {boolean} boundingMonth - Defines if we should render previous and next months in the current month view.
 *
 * @property {CalendarViewMode} startView - Defines starting view for calendar. Defaults to Date view.
 *
 * @property {(date: D) => string} title - Defines the title for visible date.
 *
 * @property {(date: D) => string} todayTitle - Defines the title for today's date.
 *
 * @property {(date: D) => boolean} filter - Predicate that decides which cells will be disabled.
 *
 * @property {(date: D) => void} onSelect - Selection emitter. Fires when another day cell is pressed.
 *
 * @property {(date: D, style: StyleType) => ReactElement} renderDay - Should return the content of day cell.
 *
 * @property {(date: D, style: StyleType) => ReactElement} renderMonth - Should return the content of month cell.
 *
 * @property {(date: D, style: StyleType) => ReactElement} renderYear - Should return the content of year cell.
 *
 * @property {ViewProps} ...ViewProps - Any props applied to View component.
 *
 * @overview-example CalendarSimpleUsage
 *
 * @overview-example CalendarBoundingMonth
 *
 * @overview-example CalendarFilter
 *
 * @overview-example CalendarBounds
 *
 * @overview-example CalendarStartDayOfWeek
 *
 * @overview-example CalendarCustomLocale
 *
 * @example CalendarMoment
 *
 * @example CalendarCustomDay
 */
export declare class CalendarComponent<D = Date> extends BaseCalendarComponent<CalendarProps<D>, D> {
    static styledComponentName: string;
    onDaySelect(date: CalendarDateInfo<D>): void;
    getDayPickerData(date: CalendarDateInfo<D>): DateBatch<D>;
    getSelectedDate(): D;
    isDaySelected(date: CalendarDateInfo<D>): boolean;
    shouldUpdateDayElement(props: CalendarPickerCellProps<D>, nextProps: CalendarPickerCellProps<D>): boolean;
}
export declare const Calendar: import("../../theme").StyledComponentClass<CalendarProps<Date>>;
export {};
