/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { FlatListProps, ListRenderItemInfo } from 'react-native';
import { StyledComponentProps, StyleType } from '../../theme';
declare type ItemType = any;
declare type ListItemElement = React.ReactElement;
declare type RenderItemProp = (info: ListRenderItemInfo<ItemType>, style: StyleType) => ListItemElement;
interface ComponentProps {
    renderItem: RenderItemProp;
}
export declare type ListProps = StyledComponentProps & FlatListProps<ItemType> & ComponentProps;
export declare type ListElement = React.ReactElement<ListProps>;
export interface BaseScrollParams {
    animated?: boolean;
}
export interface ViewScrollParams {
    viewOffset?: number;
    viewPosition?: number;
}
export interface ScrollToIndexParams extends BaseScrollParams, ViewScrollParams {
    index: number;
}
export interface ScrollToOffsetParams extends BaseScrollParams {
    offset: number;
}
/**
 * `List` component is a performant interface for rendering simple, flat lists. Extends `FlatList`. Renders list of
 * `ListItem` components or custom content.
 *
 * @extends React.Component
 *
 * @property {(info: ListRenderItemInfo<ItemT>, style: StyleType) => ReactElement} renderItem - Takes an
 * item from data and renders it into the list.
 *
 * @property {FlatListProps} ...FlatListProps - Any props applied to FlatList component.
 *
 * @overview-example ListSimpleUsage
 *
 * @overview-example ListCompositeItem
 *
 * @example ListInlineStyling
 * ```
 */
export declare class ListComponent extends React.Component<ListProps> {
    static styledComponentName: string;
    private listRef;
    scrollToEnd: (params?: BaseScrollParams) => void;
    scrollToIndex: (params: ScrollToIndexParams) => void;
    scrollToOffset(params: ScrollToOffsetParams): void;
    private getComponentStyle;
    private getItemStyle;
    private keyExtractor;
    private renderItem;
    render(): React.ReactElement<FlatListProps<ItemType>>;
}
export declare const List: import("../../theme").StyledComponentClass<ListProps>;
export {};
