/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { StyleProp, TextStyle, ViewProps } from 'react-native';
import { StyledComponentProps } from '../../theme';
import { TopNavigationActionElement } from './topNavigationAction.component';
declare type ActionElementProp = TopNavigationActionElement | TopNavigationActionElement[];
declare type AlignmentProp = 'start' | 'center';
interface ComponentProps {
    title?: string;
    titleStyle?: StyleProp<TextStyle>;
    subtitle?: string;
    subtitleStyle?: StyleProp<TextStyle>;
    alignment?: AlignmentProp;
    leftControl?: TopNavigationActionElement;
    rightControls?: ActionElementProp;
}
export declare type TopNavigationProps = StyledComponentProps & ViewProps & ComponentProps;
export declare type TopNavigationElement = React.ReactElement<TopNavigationProps>;
/**
 * `TopNavigation` component is designed to be a Navigation Bar.
 * Can be used for navigation.
 *
 * @extends React.Component
 *
 * @property {string} title - Determines the title of the component.
 *
 * @property {string} subtitle - Determines the subtitle of the component.
 *
 * @property {string} alignment - Determines the alignment of the component.
 * Can be `center` or `start`.
 * Default is `start`.
 *
 * @property {ReactElement<TopNavigationActionProps>} leftControl - Determines the left control of the component.
 *
 * @property {ReactElement<TopNavigationActionProps>[]} rightControls - Determines the right controls of the component.
 *
 * @property {StyleProp<TextStyle>} titleStyle - Customizes text style of title.
 *
 * @property {StyleProp<TextStyle>} subtitleStyle - Customizes text style of subtitle.
 *
 * @property {ViewProps} ...ViewProps - Any props applied to View component.
 *
 * @overview-example TopNavigationSimpleUsage
 *
 * @overview-example TopNavigationActions
 *
 * @overview-example TopNavigationAlignments
 *
 * @overview-example TopNavigationWithMenu
 *
 * @example TopNavigationInlineStyling
 */
export declare class TopNavigationComponent extends React.Component<TopNavigationProps> {
    static styledComponentName: string;
    private getAlignmentDependentStyles;
    private getComponentStyle;
    private renderTextElement;
    private renderActionElements;
    private renderComponentChildren;
    render(): React.ReactElement<ViewProps>;
}
export declare const TopNavigation: import("../../theme").StyledComponentClass<TopNavigationProps>;
export {};
